==> cbol-1.5.tgz: cbol-1.5/code.php <==
<?php
/*****<! !> X Cross WalkþrX ******/
function grkpar($txt,$graph)
{
  $tmp=$txt;
 $newtxt="";
 $ns=chr(34);
 while (!(($pt=strpos($tmp,"<!"))===false))
    {
        $ok1=substr($tmp,0,$pt);
        $newtxt=$newtxt.$ok1;
        $pt1=strpos($tmp,"!>");
        if ($pt1==0)
        {
           echo "error in WEB Greek parsing $tmp lost !&gt;<br>";
           return;
        }
        $grk=substr($tmp,$pt+2,$pt1-$pt-2);
          /***** Process line end 's' of Greek *****/
    	$grk=ereg_replace("s([\r\n ])","{$ns}\\1",$grk);
        $grk=ereg_replace("s$",$ns,$grk);

        if ($graph)
        {
          $grk=gfont($grk);
          $newtxt=$newtxt.$grk;
        }
        else
        {
          $grk=htmlspecialchars($grk);
          $newtxt=$newtxt."<!".$grk."!>";
        }
        $tmp=substr($tmp,$pt1+2);
    }
    $newtxt=$newtxt.$tmp;
    $txt=$newtxt;
  if ($graph==0)
  {
    $txt=ereg_replace("<!","<font face=\"BSTGreek\" size=\"5\"><nobr>",$txt);
    $txt=ereg_replace("!>","</nobr></font>",$txt);
  }
  return($txt);
}
/*****12 21 X COBSrX ******/
function hebpar($txt,$graph)
{
  $tmp=$txt;
 $newtxt="";
 while (!(($pt=strpos($tmp,"12"))===false))
    {
        $ok1=substr($tmp,0,$pt);
        $newtxt=$newtxt.$ok1;
	$oldtmp=$tmp;
        $tmp=substr($tmp,$pt+2); //TO 12 @wb 21e
        $pt1=strpos($tmp,"21");
        if ($pt1==0)
        {
           //echo "error in WEBhebpar $tmp <br>";
           //return;
	   $tmp=$oldtmp;
	   break;
        }
        $heb=substr($tmp,0,$pt1);
        if ($graph)
        {
          $heb=pfont(mscode($heb));
          $newtxt=$newtxt.$heb;
        }
        else
        {
          $heb=htmlspecialchars($heb);
          $newtxt=$newtxt."{#".$heb."#}";
        }
        $tmp=substr($tmp,$pt1+2);
    }
    $newtxt=$newtxt.$tmp;
    $txt=$newtxt;
  if ($graph==0)
  {
    $txt=ereg_replace("{#","<font face=\"COBSHebrew\" size=\"5\"><nobr>",$txt);
    $txt=ereg_replace("#}","</nobr></font>",$txt);
  }
  return($txt);
}

/*****{!  !} X Hebrew Translate rX ******/
function hebtranpar($txt,$graph)
{
  $tmp=$txt;
 $newtxt="";
 while (!(($pt=strpos($tmp,"{!"))===false))
    {
        $ok1=substr($tmp,0,$pt);
        $newtxt=$newtxt.$ok1;
        $pt1=strpos($tmp,"!}");
        if ($pt1==0)
        {
           echo "error in hebtranpar $tmp need !} <br>";
           return;
        }
        $heb=substr($tmp,$pt+2,$pt1-$pt-2);
	/*********
        if ($graph)
        {
          $heb=htfont($heb);
          $newtxt=$newtxt.$heb;
        }
        else
        *********/
        {
          $heb=htmlspecialchars($heb);
          $newtxt=$newtxt."{!".$heb."!}";
        }
        $tmp=substr($tmp,$pt1+2);
    }
    $newtxt=$newtxt.$tmp;
    $txt=$newtxt;
  if ($graph==0)
  {
    $txt=ereg_replace("{!","<font face=\"Hebrew Transliterate\" size=\"5\"><nobr>",$txt);
    $txt=ereg_replace("!}","</nobr></font>",$txt);
  }
  return($txt);
}

/***********Plft *************************/
function mscode($txt)
{
$A=array(34, 60, 62, 63, 58,  69, 73, 79, 85, 92,125);//G
$B=array(39, 44, 46, 47, 59, 101,105,111,117,124, 93);//D
$C=array(161,162,163,164,165,166,167,111,168,169,170);//k
	//70,76,102,108Mt 123AGlt79ADlt111C 
$M=array(34, 60, 62, 63, 58,  69, 73, 79, 85, 92,125,
	 39, 44, 46, 47, 59, 101,105,111,117,124, 93,
	 161,162,163,164,165,166,167,123,168,169,170); //
$TS=array(33,71,78,87,89,90,103,110,119,121,122);//Gl t $A
$SS=array(68,82,100,114);//Τlӭntukv $C
$FS=array(35,36,37,38,64,66,67,70,72,74,75,76,77,80,81,83,84,86,
	  88,91,97,98,99,102,104,106,107,108,109,112,113,115,116,117,
          118,120,126); //Dlt $B
$S=array(33,71,78,87,89,90,103,110,119,121,122,
	 68,82,100,114,
	 35,36,37,38,64,66,67,70,72,74,75,76,77,80,81,83,84,86,
          88,91,97,98,99,102,104,106,107,108,109,112,113,115,116,117,
          118,120,126);//l
   $len=strlen($txt);
    if ($len==0) return($txt);
    $ntxt="";
    for ($pt=0;$pt<$len;$pt=$pt+1)
    {
        $now=substr($txt,$pt,1);
	$cn=ord($now);
        if ($pt<($len-1)) //look aheadiHtζWLr̫
	{
                $next=substr($txt,$pt+1,1);
		$cx=ord($next);
	}
        else
	{
                $next=""; //Ŧrꤣ|b}C
		$cx=0;
	}
        if (in_array($cn,$M)&&in_array($cx,$S)) //[lAݭnBz
        {
		$aid=array_search($cn,$M);
		$aid=$aid%11;//XoOQ@ӥĴX
		//ݬݬOl
		if (in_array($cx,$FS)) //Dl
		{
			//70,76,102,108Mt 123AGlt79ADlt111C 
			//70,76,102,108 ODl
			if ((($cx==70)||($cx==76)||($cx==102)||($cx==108))
			   && (($cn==123)||($cn==79)||($cn==111)))
			   {
				$ntxt=$ntxt.chr(123).$next;
			   }
			else
                	   $ntxt=$ntxt.chr($B[$aid]).$next;
		}
		elseif (in_array($cx,$TS)) //Gl
		{
                	$ntxt=$ntxt.chr($A[$aid]).$next;
		}
		elseif (in_array($cx,$SS)) //Τl
		{
                	$ntxt=$ntxt.chr($C[$aid]).$next;
		}
		else
		{
			 echogb("S $next oӤl");
			 die('');
		}
                $pt=$pt+1;
	 }
        else //Bz
        {
                $ntxt=$ntxt.$now;
        }
    }
    $endmark=chr(96);
    /****CN ******************************/
    $nyes=chr(167)."~;l'vWr>y";
    $ntxt=str_replace("i~;l'vWr>y",$nyes,$ntxt);
    $nyes=chr(167)."~'l'vWryIw";
    $ntxt=str_replace("i~'l'vWryIw",$nyes,$ntxt);
    $nyes=chr(167)."~;l'vWryIw";
    $ntxt=str_replace("i~;l'vWryIw",$nyes,$ntxt);
    /******S*******/
    $yes="(-;H)";
    $nyes="-".chr(165).chr(72);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="(^;H)";
    $nyes=chr(165).chr(72);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="( ;H)";
    $nyes=" ".chr(165)."H";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="(\n;H)";
    $nyes="\n".chr(165)."H";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="({$endmark};H)";
    $nyes="$endmark".chr(165)."H";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);

    $yes="-;\[";
    $nyes="-".chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="^;\[";
    $nyes=chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes=" ;\[";
    $nyes=" ".chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="\n;\[";
    $nyes="\n".chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="{$endmark};\[";
    $nyes="$endmark".chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);

    $yes="(-;x)";
    $nyes="-".chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="(^;x)";
    $nyes=chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="( ;x)";
    $nyes=" ".chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="(\n;x)";
    $nyes="\n".chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $endmark=chr(96);
    $yes="({$endmark};x)";
    $nyes="$endmark".chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    /****Ÿ******/
    return($ntxt);
}


?>

==> cbol-3.0.tgz: cbol-3.0/code.php <==
<?php
/*****[#5.3#]  X 5.3  ******/
function hgarref($txt)
{
  $tmp=$txt;
 $newtxt="";
 while (!(($pt=strpos($tmp,'[#'))===false))
    {
        $ok1=substr($tmp,0,$pt);
        $newtxt=$newtxt.$ok1;
        $oldtmp=$tmp;
        $tmp=substr($tmp,$pt+2); //TO12b21e
        $pt1=strpos($tmp,'#]');
        if ($pt1==0)
        {
           //echo "error in WEBhebpar $tmp <br>";
           //return;
           $tmp=$oldtmp;
           break;
        }
        $heb=substr($tmp,0,$pt1);
	$heb=str_replace('','1',$heb);
        $heb=str_replace('','2',$heb);
        $heb=str_replace('','3',$heb);
        $heb=str_replace('','4',$heb);
        $heb=str_replace('','5',$heb);
        $heb=str_replace('','6',$heb);
        $heb=str_replace('','7',$heb);
        $heb=str_replace('','8',$heb);
        $heb=str_replace('','9',$heb);
        $heb=str_replace('D','.',$heb);
        //$newtxt=$newtxt.'ݧƧBӤŪg'.$heb.'C';
        $newtxt=$newtxt.''.$heb;
        $tmp=substr($tmp,$pt1+2);
    }
    $newtxt=$newtxt.$tmp;
    $newtxt;

  return($newtxt);
}
/*****<! !> X Cross WalkþrX ******/
function grkpar($txt,$graph)
{
  $tmp=$txt;
 $newtxt="";
 $ns=chr(34);
 while (!(($pt=strpos($tmp,"<!"))===false))
    {
        $ok1=substr($tmp,0,$pt);
        $newtxt=$newtxt.$ok1;
        $pt1=strpos($tmp,"!>");
        if ($pt1==0)
        {
           echo "error in WEB Greek parsing $tmp lost !&gt;<br>";
           return;
        }
        $grk=substr($tmp,$pt+2,$pt1-$pt-2);
        if ($graph)
        {
          $grk=gfont(gcode($grk,1));
          $newtxt=$newtxt.$grk;
        }
        else
        {
          $grk=htmlspecialchars(gcode($grk,0));
          $newtxt=$newtxt."<!".$grk."!>";
        }
        $tmp=substr($tmp,$pt1+2);
    }
    $newtxt=$newtxt.$tmp;
    $txt=$newtxt;
  if ($graph==0)
  {
    $txt=ereg_replace("<!","<font face=\"COBSGreek\" size=\"5\"><nobr>",$txt);
    $txt=ereg_replace("!>","</nobr></font>",$txt);
  }
  return($txt);
}
/*****12 21 X COBSrX ******/
function hebpar($txt,$graph)
{
  $tmp=$txt;
 $newtxt="";
 while (!(($pt=strpos($tmp,"12"))===false))
    {
        $ok1=substr($tmp,0,$pt);
        $newtxt=$newtxt.$ok1;
	$oldtmp=$tmp;
        $tmp=substr($tmp,$pt+2); //TO 12 @wb 21e
        $pt1=strpos($tmp,"21");
        if ($pt1==0)
        {
           //echo "error in WEBhebpar $tmp <br>";
           //return;
	   $tmp=$oldtmp;
	   break;
        }
        $heb=substr($tmp,0,$pt1);
        if ($graph)
        {
          $heb=pfont(mscode($heb));
          $newtxt=$newtxt.$heb;
        }
        else
        {
          $heb=htmlspecialchars($heb);
          $newtxt=$newtxt."{#".$heb."#}";
        }
        $tmp=substr($tmp,$pt1+2);
    }
    $newtxt=$newtxt.$tmp;
    $txt=$newtxt;
  if ($graph==0)
  {
    $txt=ereg_replace("{#","<font face=\"COBSHebrew\" size=\"5\"><nobr>",$txt);
    $txt=ereg_replace("#}","</nobr></font>",$txt);
  }
  return($txt);
}

/*****{!  !} X Hebrew Translate rX ******/
function hebtranpar($txt,$graph)
{
  $tmp=$txt;
 $newtxt="";
 while (!(($pt=strpos($tmp,"{!"))===false))
    {
        $ok1=substr($tmp,0,$pt);
        $newtxt=$newtxt.$ok1;
        $pt1=strpos($tmp,"!}");
        if ($pt1==0)
        {
           echo "error in hebtranpar $tmp need !} <br>";
           return;
        }
        $heb=substr($tmp,$pt+2,$pt1-$pt-2);
	/*********
        if ($graph)
        {
          $heb=htfont($heb);
          $newtxt=$newtxt.$heb;
        }
        else
        *********/
        {
          $heb=htmlspecialchars($heb);
          $newtxt=$newtxt."{!".$heb."!}";
        }
        $tmp=substr($tmp,$pt1+2);
    }
    $newtxt=$newtxt.$tmp;
    $txt=$newtxt;
  if ($graph==0)
  {
    $txt=ereg_replace("{!","<font face=\"Hebrew Transliterate\" size=\"5\"><nobr>",$txt);
    $txt=ereg_replace("!}","</nobr></font>",$txt);
  }
  return($txt);
}

/***********Plft *************************/
function mscode($txt)
{
$A=array(34, 60, 62, 63, 58,  69, 73, 79, 85, 92,125);//G
$B=array(39, 44, 46, 47, 59, 101,105,111,117,124, 93);//D
$C=array(161,162,163,164,165,166,167,111,168,169,170);//k
	//70,76,102,108Mt 123AGlt79ADlt111C 
$M=array(34, 60, 62, 63, 58,  69, 73, 79, 85, 92,125,
	 39, 44, 46, 47, 59, 101,105,111,117,124, 93,
	 161,162,163,164,165,166,167,123,168,169,170); //
$TS=array(33,71,78,87,89,90,103,110,119,121,122);//Gl t $A
$SS=array(68,82,100,114);//Τlӭntukv $C
$FS=array(35,36,37,38,64,66,67,70,72,74,75,76,77,80,81,83,84,86,
	  88,91,97,98,99,102,104,106,107,108,109,112,113,115,116,117,
          118,120,126); //Dlt $B
$S=array(33,71,78,87,89,90,103,110,119,121,122,
	 68,82,100,114,
	 35,36,37,38,64,66,67,70,72,74,75,76,77,80,81,83,84,86,
          88,91,97,98,99,102,104,106,107,108,109,112,113,115,116,117,
          118,120,126);//l
   $len=strlen($txt);
    if ($len==0) return($txt);
    $ntxt="";
    for ($pt=0;$pt<$len;$pt=$pt+1)
    {
        $now=substr($txt,$pt,1);
	$cn=ord($now);
        if ($pt<($len-1)) //look aheadiHtζWLr̫
	{
                $next=substr($txt,$pt+1,1);
		$cx=ord($next);
	}
        else
	{
                $next=""; //Ŧrꤣ|b}C
		$cx=0;
	}
        if (in_array($cn,$M)&&in_array($cx,$S)) //[lAݭnBz
        {
		$aid=array_search($cn,$M);
		$aid=$aid%11;//XoOQ@ӥĴX
		//ݬݬOl
		if (in_array($cx,$FS)) //Dl
		{
			//70,76,102,108Mt 123AGlt79ADlt111C 
			//70,76,102,108 ODl
			if ((($cx==70)||($cx==76)||($cx==102)||($cx==108))
			   && (($cn==123)||($cn==79)||($cn==111)))
			   {
				$ntxt=$ntxt.chr(123).$next;
			   }
			else
                	   $ntxt=$ntxt.chr($B[$aid]).$next;
		}
		elseif (in_array($cx,$TS)) //Gl
		{
                	$ntxt=$ntxt.chr($A[$aid]).$next;
		}
		elseif (in_array($cx,$SS)) //Τl
		{
                	$ntxt=$ntxt.chr($C[$aid]).$next;
		}
		else
		{
			 echogb("S $next oӤl");
			 die('');
		}
                $pt=$pt+1;
	 }
        else //Bz
        {
                $ntxt=$ntxt.$now;
        }
    }
    $endmark=chr(96);
    /****CN ******************************/
    $nyes=chr(167)."~;l'vWr>y";
    $ntxt=str_replace("i~;l'vWr>y",$nyes,$ntxt);
    $nyes=chr(167)."~'l'vWryIw";
    $ntxt=str_replace("i~'l'vWryIw",$nyes,$ntxt);
    $nyes=chr(167)."~;l'vWryIw";
    $ntxt=str_replace("i~;l'vWryIw",$nyes,$ntxt);
    /******S*******/
    $yes="(-;H)";
    $nyes="-".chr(165).chr(72);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="(^;H)";
    $nyes=chr(165).chr(72);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="( ;H)";
    $nyes=" ".chr(165)."H";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="(\n;H)";
    $nyes="\n".chr(165)."H";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="({$endmark};H)";
    $nyes="$endmark".chr(165)."H";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);

    $yes="-;\[";
    $nyes="-".chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="^;\[";
    $nyes=chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes=" ;\[";
    $nyes=" ".chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="\n;\[";
    $nyes="\n".chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="{$endmark};\[";
    $nyes="$endmark".chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);

    $yes="(-;x)";
    $nyes="-".chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="(^;x)";
    $nyes=chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="( ;x)";
    $nyes=" ".chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="(\n;x)";
    $nyes="\n".chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $endmark=chr(96);
    $yes="({$endmark};x)";
    $nyes="$endmark".chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    /****Ÿ******/
    return($ntxt);
}
function gcode($itxt,$graph)
{
 $iepuno=array(118, 59,106, 74, 39, 92,124, 91, 93, 38, 94);
 //$iepunn=array( 17, 18, 19, 20, 21, 22, 23, 28, 29, 30, 31);
 $iepunn=array(161,162,163,164,165,166,167,168,169,170,171);
 $Bpuno=array(106, 74, 92,124, 91, 93, 38, 94);
 $Bpunn=array( 36, 37, 42, 43,126, 60, 33, 64);
 //$Bpunn=array(179,180,182,183,184,185,186,187);
 $BList=array('A','I','E','U','H','O','W','R');
 $len=strlen($itxt);
 if ($len==0) return($itxt);
 /***** Process line end 's' of Greek *****/
 $ns=chr(34);
 $txt=ereg_replace("s([\r\n,.:;}{ ])","{$ns}\\1",$itxt);
 $txt=ereg_replace("s$",$ns,$txt);
 /**** BzP ***/
 $ntxt=substr($txt,0,1);//Ĥ@Ӧr
 for ($pt=1;$pt<$len;$pt=$pt+1)//|b@}Y
 {
        $flag=0;
        $now=substr($txt,$pt,1);
        $key=array_search(ord($now), $iepuno);
        if ($key!==false && $graph==1)
        {
                $pre=substr($txt,$pt-1,1);
                if (strcmp($pre,'i')==0||strcmp($pre,'e')==0) //match
		{
                        $ntxt=$ntxt.chr($iepunn[$key]);
                	$flag=1;
		}
        }
         $key=array_search(ord($now), $Bpuno);
        if ($key!==false && $flag==0)
        {
                $pre=substr($txt,$pt-1,1);
                if (in_array($pre,$BList)) //match
		{
                        $ntxt=$ntxt.chr($Bpunn[$key]);
                	$flag=1;
		}
        }
        if ($flag==0) $ntxt=$ntxt.$now;
 }//for pt
 return $ntxt;
}

?>
